@@ -28,7 +28,7 @@ class EtsyAuth:
     def __post_init__(self):
         user_info_endpoint = "oauth/userinfo"
         
-        response = self.request("GET", user_info_endpoint)
+        response = self.request(user_info_endpoint)
         
         setattr(self, "user_info", OtherUser(**response))
         
